@@ -116,6 +116,7 @@ impl MarkPane {
             Char('x') | Char('d') | Char(' ') => {
                 return self.remove_selected().map(|s| (s, action))
             }
+            Char('a') => return None,
             Char('H') => self.change_selection(CursorDirection::ToTop),
             Char('G') => self.change_selection(CursorDirection::ToBottom),
             Ctrl('u') | PageUp => self.change_selection(CursorDirection::PageUp),
@@ -411,7 +412,7 @@ impl MarkPane {
                 );
             }
             let bound = line_bound(bound, bound.height.saturating_sub(1) as usize);
-            let help_text = " mark-toggle = space|d";
+            let help_text = " mark-toggle = space,d | remove-all = a";
             let help_text_block_width = block_width(help_text);
             if help_text_block_width <= bound.width {
                 draw_text_nowrap_fn(
